
TODO_42_81_01_90: assert data instead of captured print out (stdout, stderr)

It should be possible to intercept data and assert it in tests for all operations.
Currently, only invocation data is intercepted.
